@@ -1,3 +1,6 @@
+#ifndef QT_FEATURES_Graphs_src_qtgraphs_config_h_H
+#define QT_FEATURES_Graphs_src_qtgraphs_config_h_H
+
 #define QT_FEATURE_graphs_2d 1
 
 #define QT_FEATURE_graphs_2d_area 1
@@ -20,3 +23,5 @@
 
 #define QT_FEATURE_graphs_3d_surface3d 1
 
+
+#endif // QT_FEATURES_Graphs_src_qtgraphs_config_h_H
